# Mercury-ML Overview

In the ancient Roman mythology, the god Mercury was known as the messenger of the god. Wearing winged shoes and a winged 
hat he zipped between Mount Olympus and the kingdoms of men and saw to it that the will of the gods was known.

We've chosen `Mercury-ML` as the name of this package because we see its role as very similar. 

Recent developments in Machine Learning and Data Processing tools have lead to a myriad of except open source libraries 
each of which provide well developed and transparent APIs. Where it becomes more complicated is when functions from 
different libraries need to be strung together to form a machine learning workflow. `Mercury-ML` is "a messenger of the gods" 
that enables this to happen. It seeks to break down a Machine Learning project into its typical generic components 
(such as `read data`, `transform data`, `fit model`, `evaluate model` etc.) and offers a generic modular structure where 
implementations for specific methods and technologies can slot in.

These broken down components can then be chained together into a coherent, easily configurable and Workflow for fitting 
and evaluating Machine Learning models. We saying "fitting" and "evaluating", not "inference". One could use `Mercury-ML` 
for inference as well, but that is not its main goal. It mainly concerns itself putting in place and scalable, transparent 
and repeatable process for the manufacture (and subsequent storage) of machine learning models

PLEASE STAY TUNED. THERE FIRST VERSION OF THIS CODE WILL BE AVAILABLE SOON.